@@ -5,6 +5,7 @@ import Test.QuickCheck
 import Test.QuickCheck.Instances ()
 
 import qualified Data.Tree as Tree
+import qualified Data.Primitive as Prim
 import           Data.UUID.Types (UUID)
 
 -- | Example law: == (and thus ===) should be reflexive.
@@ -20,3 +21,4 @@ main = do
     quickCheck $ eqReflexive (Proxy :: Proxy Int)
     quickCheck $ eqReflexive (Proxy :: Proxy (Tree.Tree Int))
     quickCheck $ eqReflexive (Proxy :: Proxy UUID)
+    quickCheck $ eqReflexive (Proxy :: Proxy Prim.ByteArray)
